@@ -7,7 +7,7 @@ from loguru import logger
 from tqdm import tqdm
 
 from genomepy.annotation.utils import _parse_annot
-from genomepy.caching import cache_exp_short, disk_cache, lock
+from genomepy.caching import cache_exp_other, disk_cache, lock
 
 
 def _map_genes(
@@ -79,7 +79,7 @@ def _map_genes(
 
 
 @lock
-@disk_cache.memoize(expire=cache_exp_short, tag="query_mygene")
+@disk_cache.memoize(expire=cache_exp_other, tag="query_mygene")
 def query_mygene(
     query: Iterable[str],
     tax_id: Union[str, int],
