@@ -1,8 +1,5 @@
-"""Exceptions for the genomepy module."""
-
-
 class GenomeDownloadError(Exception):
 
     """Error while downloading genome."""
 
-    pass
+    pass  # noqa
