@@ -3,7 +3,7 @@ import re
 import requests
 from loguru import logger
 
-from genomepy.caching import cache_exp_long, cache_exp_short, disk_cache, lock
+from genomepy.caching import cache_exp_genomes, cache_exp_other, disk_cache, lock
 from genomepy.exceptions import GenomeDownloadError
 from genomepy.online import check_url, retry
 from genomepy.providers.base import BaseProvider
@@ -69,7 +69,7 @@ class EnsemblProvider(BaseProvider):
 
     @staticmethod
     @lock
-    @disk_cache.memoize(expire=cache_exp_short, tag="get_version-ensembl")
+    @disk_cache.memoize(expire=cache_exp_other, tag="get_version-ensembl")
     def get_version(vertebrates=False, set_version=None, url=_url):
         """Retrieve current version from Ensembl FTP."""
         if set_version:
@@ -244,7 +244,7 @@ def add_grch37(genomes):
 
 
 @lock
-@disk_cache.memoize(expire=cache_exp_long, tag="get_genomes-ensembl")
+@disk_cache.memoize(expire=cache_exp_genomes, tag="get_genomes-ensembl")
 def get_genomes(rest_url):
     logger.info("Downloading assembly summaries from Ensembl")
 
